from pydantic.dataclasses import dataclass
from travelperk_python_api_types.travelsafe.category import Category


@dataclass
class SafetyMeasure:
    category: Category
    sub_category: Category
    details: str
    summary: str



from pydantic.dataclasses import dataclass
from typing import List
from .cost_center import CostCenter


@dataclass
class CostCenters:
    offset: int
    limit: int
    cost_centers: List[CostCenter]



from typing import List
from pydantic.dataclasses import dataclass
from .user import User


@dataclass
class CostCenterDetail:
    id: str
    name: str
    archived: bool
    users: List[User]
    count_users: int



from typing import List
from pydantic.dataclasses import dataclass
from .airline import Airline
from travelperk_python_api_types.travelsafe.info_source import InfoSource
from .safety_measure import SafetyMeasure


@dataclass
class AirlineMeasure:
    airline: Airline
    safety_measures: List[SafetyMeasure]
    info_source: InfoSource
    updated_at: str



from typing import List
from pydantic.dataclasses import dataclass
from travelperk_python_api_types.travelsafe.location import Location
from .requirement import Requirement
from travelperk_python_api_types.travelsafe.info_source import InfoSource


@dataclass
class Restriction:
    origin: Location
    destination: Location
    authorization_status: str
    summary: str
    details: str
    start_date: str
    updated_at: str
    requirements: List[Requirement]
    info_source: InfoSource
    end_date: str = None



from typing import List
from pydantic.dataclasses import dataclass
from travelperk_python_api_types.expenses.invoice_lines.invoice_line import InvoiceLine


@dataclass
class Lines:
    total: str
    data: List[InvoiceLine]
    next: str



from typing import List
from pydantic.dataclasses import dataclass
from .invoice_profile import InvoiceProfile
from .emergency_contact import EmergencyContact


@dataclass
class TravelperkExtension:
    invoice_profiles: List[InvoiceProfile]
    emergency_contact: EmergencyContact
    gender: str = None
    date_of_birth: str = None
    travel_policy: str = None
    country_or_residence: str = None



from typing import List
from pydantic.dataclasses import dataclass
from .name import Name
from .phone_number import PhoneNumber
from .meta import Meta
from .enterprise_extension import EnterpriseExtension
from .travelperk_extension import TravelperkExtension


@dataclass
class User:
    schemas: List[str]
    name: Name
    locale: str
    preferred_language: str
    id: str
    groups: List[str]
    active: str
    user_name: str
    phone_numbers: List[PhoneNumber]
    enterprise_extension: EnterpriseExtension
    travelperk_extension: TravelperkExtension
    title: str = None
    external_id: str = None
    meta: Meta = None



from pydantic.dataclasses import dataclass
from travelperk_python_api_types.expenses.billing_information import BillingInformation


@dataclass
class InvoiceProfile:
    id: str
    name: str
    payment_method_type: str
    billing_period: str
    currency: str
    billing_information: BillingInformation



from typing import List
from pydantic.dataclasses import dataclass
from .risk_level import RiskLevel
from travelperk_python_api_types.travelsafe.location import Location
from .guideline import Guideline
from travelperk_python_api_types.travelsafe.info_source import InfoSource


@dataclass
class Summary:
    summary: str
    details: str
    risk_level: RiskLevel
    location: Location
    updated_at: str
    guidelines: List[Guideline]
    info_source: InfoSource = None



from pydantic.dataclasses import dataclass
from .metadata import Metadata


@dataclass
class InvoiceLine:
    expense_date: str
    description: str
    quantity: int
    unit_price: str
    non_taxable_unit_price: str
    tax_percentage: str
    tax_amount: str
    tax_regime: str
    total_amount: str
    metadata: Metadata
    invoice_serial_number: str = None
    profile_id: str = None
    profile_name: str = None
    invoice_mode: str = None
    invoice_status: str = None
    issuing_date: str = None
    due_date: str = None
    currency: str = None



from typing import List
from pydantic.dataclasses import dataclass
from travelperk_python_api_types.travelsafe.category import Category
from .document import Document


@dataclass
class Requirement:
    category: Category
    sub_category: Category
    summary: str
    details: str
    start_date: str
    documents: List[Document]
    end_date: str = None



from typing import List
from pydantic.dataclasses import dataclass
from .location import Location
from .reference import Reference
from .leg import Leg


@dataclass
class Booking:
    id: str
    start: str
    end: str
    type: str
    status: str
    modified: str
    trip_id: str
    references: List[Reference]
    location: Location = None
    legs: List[Leg] = None



from typing import List
from pydantic.dataclasses import dataclass


@dataclass
class Webhook:
    id: str
    name: str
    url: str
    secret: str
    enabled: bool
    events: List[str]
    successfully_sent: int
    failed_sent: int
    error_rate: float



from typing import List
from pydantic.dataclasses import dataclass
from .invoice_line import InvoiceLine


@dataclass
class InvoiceLines:
    offset: int
    limit: int
    total: int
    invoice_lines: List[InvoiceLine]



from typing import List
from pydantic.dataclasses import dataclass
from .user import User
from .vendor import Vendor


@dataclass
class Metadata:
    service: str
    travelers: List[User]
    approvers: List[User]
    trip_id: int = None
    trip_name: str = None
    start_date: str = None
    end_date: str = None
    cost_center: str = None
    labels: List[str] = None
    vendor: Vendor = None
    out_of_policy: bool = None
    booker: User = None
    service_location: str = None
    include_breakfast: bool = None



from pydantic.dataclasses import dataclass
from travelperk_python_api_types.travelsafe.category import Category


@dataclass
class Guideline:
    category: Category
    sub_category: Category
    summary: str
    details: str
    severity: str



from pydantic.dataclasses import dataclass
from .origin import Origin
from .destination import Destination


@dataclass
class Segment:
    origin: Origin
    destination: Destination
    external_id: str



from pydantic.dataclasses import dataclass


@dataclass
class BillingInformation:
    legal_name: str
    vat_number: str
    address_line_1: str
    address_line_2: str
    city: str
    postal_code: str
    country_name: str



from typing import List
from pydantic.dataclasses import dataclass
from .invoice_profile import InvoiceProfile


@dataclass
class InvoiceProfiles:
    offset: int
    limit: int
    total: int
    profiles: List[InvoiceProfile]



from typing import List
from pydantic.dataclasses import dataclass
from travelperk_python_api_types.expenses.billing_information import BillingInformation
from .lines import Lines
from .taxes_summary import TaxesSummary
from .travelperk_bank_account import TravelperkBankAccount


@dataclass
class Invoice:
    serial_number: str
    profile_id: str
    profile_name: str
    billing_information: BillingInformation
    mode: str
    status: str
    issuing_date: str
    billing_period: str
    from_date: str
    to_date: str
    due_date: str
    currency: str
    total: str
    taxes_summary: List[TaxesSummary]
    reference: str
    pdf: str
    lines: Lines = None
    travelperk_bank_account: TravelperkBankAccount = None



from typing import List
from pydantic.dataclasses import dataclass
from .user import User


@dataclass
class Users:
    schemas: List[str]
    total_results: int
    items_per_page: int
    start_index: int
    resources: List[User]



from typing import List
from pydantic.dataclasses import dataclass
from .name import Name
from .emergency_contact import EmergencyContact


@dataclass
class User:
    id: str
    user_name: str
    name: Name
    preferred_language: str
    locale: str
    active: bool
    phone_numbers: List[str]
    job_title: str = None
    emergency_contact: EmergencyContact = None
